@@ -16,9 +16,13 @@ from .operators.inversion import pixelizations as pix, regularization as reg
 from .operators.inversion.inversions import inversion as Inversion
 from .operators.inversion.mappers import mapper as Mapper
 from .operators.transformer import TransformerDFT
-from .operators.transformer import TransformerFFT
 from .operators.transformer import TransformerNUFFT
 from .structures.arrays import Array, Values
+from .structures.arrays.abstract_array import ExposureInfo
+from .structures.frame import Frame
+from .structures.instruments.euclid import FrameEuclid
+from .structures.instruments.acs import FrameACS
+from .structures.frame.abstract_frame import Scans
 from .structures.grids import (
     Grid,
     GridIterate,
@@ -26,10 +30,10 @@ from .structures.grids import (
     GridRectangular,
     GridVoronoi,
     GridCoordinates,
+    GridCoordinatesUniform,
 )
+from .structures.region import Region
 from .structures.kernel import Kernel
 from .structures.visibilities import Visibilities
-from .structures.arrays import MaskedArray
-from .structures.grids import MaskedGrid
 
-__version__ = '0.11.11'
+__version__ = '0.12.0'
