@@ -1,6 +1,7 @@
 import pickle
 
 import numpy as np
+import copy
 
 from autoarray.structures import arrays, grids
 
@@ -117,6 +118,14 @@ class AbstractDataset:
         """The maximum value of the potential chi-squared-map"""
         return np.max(self.potential_chi_squared_map)
 
+    def modify_noise_map(self, noise_map):
+
+        imaging = copy.deepcopy(self)
+
+        imaging.noise_map = noise_map
+
+        return imaging
+
 
 class AbstractMaskedDataset:
     def __init__(
@@ -175,3 +184,11 @@ class AbstractMaskedDataset:
     @property
     def positions(self):
         return self.dataset.positions
+
+    def modify_noise_map(self, noise_map):
+
+        masked_imaging = copy.deepcopy(self)
+
+        masked_imaging.noise_map = noise_map
+
+        return masked_imaging
