@@ -71,15 +71,9 @@ class GridIterate(abstract_grid.AbstractGrid):
         obj = grid.view(cls)
         obj.mask = mask
         obj.store_in_1d = store_in_1d
-
-        if len(obj.shape) == 2:
-            obj.grid = grids.MaskedGrid.manual_1d(
-                grid=np.asarray(obj), mask=mask, store_in_1d=store_in_1d
-            )
-        elif len(obj.shape) == 3:
-            obj.grid = grids.MaskedGrid.manual_2d(
-                grid=np.asarray(obj), mask=mask, store_in_1d=store_in_1d
-            )
+        obj.grid = grids.Grid.manual_mask(
+            grid=np.asarray(obj), mask=mask, store_in_1d=store_in_1d
+        )
         obj.fractional_accuracy = fractional_accuracy
         obj.sub_steps = sub_steps
         return obj
@@ -126,7 +120,7 @@ class GridIterate(abstract_grid.AbstractGrid):
             If True, the grid is stored in 1D as an ndarray of shape [total_unmasked_pixels, 2]. If False, it is
             stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels, 2].
         """
-        grid = abstract_grid.convert_and_check_grid(grid=grid)
+        grid = abstract_grid.convert_grid(grid=grid)
         pixel_scales = abstract_structure.convert_pixel_scales(
             pixel_scales=pixel_scales
         )
